@@ -13,6 +13,8 @@ from ormar.fields import (
     String,
     Text,
     Time,
+    UUID,
+    UniqueColumns,
 )
 from ormar.models import Model
 from ormar.queryset import QuerySet
@@ -26,7 +28,7 @@ class UndefinedType:  # pragma no cover
 
 Undefined = UndefinedType()
 
-__version__ = "0.3.5"
+__version__ = "0.3.6"
 __all__ = [
     "Integer",
     "BigInteger",
@@ -49,4 +51,6 @@ __all__ = [
     "QuerySet",
     "RelationType",
     "Undefined",
+    "UUID",
+    "UniqueColumns",
 ]
