@@ -1,5 +1,5 @@
 import itertools
-from typing import Any, List, Tuple, Union
+from typing import Any, Dict, List, Optional
 
 import sqlalchemy
 from databases.backends.postgres import Record
@@ -9,8 +9,8 @@ from ormar.fields.many_to_many import ManyToManyField
 from ormar.models import NewBaseModel  # noqa I100
 
 
-def group_related_list(list_: List) -> dict:
-    test_dict = dict()
+def group_related_list(list_: List) -> Dict:
+    test_dict: Dict[str, Any] = dict()
     grouped = itertools.groupby(list_, key=lambda x: x.split("__")[0])
     for key, group in grouped:
         group_list = list(group)
@@ -28,15 +28,16 @@ class Model(NewBaseModel):
     __abstract__ = False
 
     @classmethod
-    def from_row(
+    def from_row(  # noqa CCR001
         cls,
         row: sqlalchemy.engine.ResultProxy,
         select_related: List = None,
         related_models: Any = None,
         previous_table: str = None,
-    ) -> Union["Model", Tuple["Model", dict]]:
+        fields: List = None,
+    ) -> Optional["Model"]:
 
-        item = {}
+        item: Dict[str, Any] = {}
         select_related = select_related or []
         related_models = related_models or []
         if select_related:
@@ -52,15 +53,20 @@ class Model(NewBaseModel):
                 previous_table
             ].through.Meta.tablename
 
-        table_prefix = cls.Meta.alias_manager.resolve_relation_join(
-            previous_table, cls.Meta.table.name
-        )
+        if previous_table:
+            table_prefix = cls.Meta.alias_manager.resolve_relation_join(
+                previous_table, cls.Meta.table.name
+            )
+        else:
+            table_prefix = ""
         previous_table = cls.Meta.table.name
 
         item = cls.populate_nested_models_from_row(
-            item, row, related_models, previous_table
+            item, row, related_models, previous_table, fields
+        )
+        item = cls.extract_prefixed_table_columns(
+            item, row, table_prefix, fields, nested=table_prefix != ""
         )
-        item = cls.extract_prefixed_table_columns(item, row, table_prefix)
 
         instance = cls(**item) if item.get(cls.Meta.pkname, None) is not None else None
         return instance
@@ -72,33 +78,47 @@ class Model(NewBaseModel):
         row: sqlalchemy.engine.ResultProxy,
         related_models: Any,
         previous_table: sqlalchemy.Table,
+        fields: List = None,
     ) -> dict:
         for related in related_models:
             if isinstance(related_models, dict) and related_models[related]:
                 first_part, remainder = related, related_models[related]
                 model_cls = cls.Meta.model_fields[first_part].to
                 child = model_cls.from_row(
-                    row, related_models=remainder, previous_table=previous_table
+                    row,
+                    related_models=remainder,
+                    previous_table=previous_table,
+                    fields=fields,
                 )
                 item[first_part] = child
             else:
                 model_cls = cls.Meta.model_fields[related].to
-                child = model_cls.from_row(row, previous_table=previous_table)
+                child = model_cls.from_row(
+                    row, previous_table=previous_table, fields=fields
+                )
                 item[related] = child
 
         return item
 
     @classmethod
     def extract_prefixed_table_columns(  # noqa CCR001
-        cls, item: dict, row: sqlalchemy.engine.result.ResultProxy, table_prefix: str
+        cls,
+        item: dict,
+        row: sqlalchemy.engine.result.ResultProxy,
+        table_prefix: str,
+        fields: List = None,
+        nested: bool = False,
     ) -> dict:
+
+        # databases does not keep aliases in Record for postgres, change to raw row
+        source = row._row if isinstance(row, Record) else row
+
+        selected_columns = cls.own_table_columns(cls, fields or [], nested=nested)
         for column in cls.Meta.table.columns:
-            if column.name not in item:
+            if column.name not in item and column.name in selected_columns:
                 prefixed_name = (
                     f'{table_prefix + "_" if table_prefix else ""}{column.name}'
                 )
-                # databases does not keep aliases in Record for postgres
-                source = row._row if isinstance(row, Record) else row
                 item[column.name] = source[prefixed_name]
 
         return item
@@ -106,7 +126,7 @@ class Model(NewBaseModel):
     async def save(self) -> "Model":
         self_fields = self._extract_model_db_fields()
 
-        if not self.pk and self.Meta.model_fields.get(self.Meta.pkname).autoincrement:
+        if not self.pk and self.Meta.model_fields[self.Meta.pkname].autoincrement:
             self_fields.pop(self.Meta.pkname, None)
         self_fields = self.objects._populate_default_values(self_fields)
         expr = self.Meta.table.insert()
@@ -138,5 +158,9 @@ class Model(NewBaseModel):
     async def load(self) -> "Model":
         expr = self.Meta.table.select().where(self.pk_column == self.pk)
         row = await self.Meta.database.fetch_one(expr)
+        if not row:  # pragma nocover
+            raise ValueError(
+                "Instance was deleted from database and cannot be refreshed"
+            )
         self.from_dict(dict(row))
         return self
