@@ -1,4 +1,4 @@
-from typing import List, TYPE_CHECKING, Tuple, Type
+from typing import List, Optional, TYPE_CHECKING, Tuple, Type
 
 import sqlalchemy
 from sqlalchemy import text
@@ -18,30 +18,37 @@ class Query:
         filter_clauses: List,
         exclude_clauses: List,
         select_related: List,
-        limit_count: int,
-        offset: int,
+        limit_count: Optional[int],
+        offset: Optional[int],
+        fields: Optional[List],
     ) -> None:
         self.query_offset = offset
         self.limit_count = limit_count
         self._select_related = select_related[:]
         self.filter_clauses = filter_clauses[:]
         self.exclude_clauses = exclude_clauses[:]
+        self.fields = fields[:] if fields else []
 
         self.model_cls = model_cls
         self.table = self.model_cls.Meta.table
 
-        self.used_aliases = []
+        self.used_aliases: List[str] = []
 
-        self.select_from = None
-        self.columns = None
-        self.order_bys = None
+        self.select_from: List[str] = []
+        self.columns = [sqlalchemy.Column]
+        self.order_bys: List[sqlalchemy.sql.elements.TextClause] = []
 
     @property
     def prefixed_pk_name(self) -> str:
         return f"{self.table.name}.{self.model_cls.Meta.pkname}"
 
     def build_select_expression(self) -> Tuple[sqlalchemy.sql.select, List[str]]:
-        self.columns = list(self.table.columns)
+        self_related_fields = self.model_cls.own_table_columns(
+            self.model_cls, self.fields
+        )
+        self.columns = self.model_cls.Meta.alias_manager.prefixed_columns(
+            "", self.table, self_related_fields
+        )
         self.order_bys = [text(self.prefixed_pk_name)]
         self.select_from = self.table
 
@@ -57,6 +64,7 @@ class Query:
                 select_from=self.select_from,
                 columns=self.columns,
                 order_bys=self.order_bys,
+                fields=self.fields,
             )
 
             (
@@ -89,7 +97,8 @@ class Query:
         return expr
 
     def _reset_query_parameters(self) -> None:
-        self.select_from = None
-        self.columns = None
-        self.order_bys = None
+        self.select_from = []
+        self.columns = []
+        self.order_bys = []
         self.used_aliases = []
+        self.fields = []
